package com.example.game;

import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;
import android.widget.Button;

/**
 * Clase utilizada para producir el efecto de expansin de un control visual cuando lo pulsamos.
 * Volviendo a su tamao original cuando finalizamos la pulsacin.
 * 
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class ButtonExpanderOnTouchListener implements OnTouchListener {

	  final Button _objectButton;
	  
	  private float _originalSize = 0;
	  private float _sizeToExpander = 0;

	  public ButtonExpanderOnTouchListener(final Button objectButton) {
	    super();
	    this._objectButton = objectButton;
	    
	    /* Este tamao es en pixeles y dependiente de la densidad de pantalla del dispositivo. Debo pasarlo a la unidad "sp".
	     * Para ello, divido el tamao en pixeles en el dispositivo actual entre la densidad de pantalla.
	     */
	    _originalSize = _objectButton.getTextSize();
	    _originalSize = _originalSize / MyApplication.getDensityScreen();
	    
	    //Incrementamos el tamao 1.5 veces el tamao original
	    _sizeToExpander = (float) (_originalSize * 1.5);  
	  }

	  public boolean onTouch(final View view, final MotionEvent motionEvent) {
	    if (motionEvent.getAction() == MotionEvent.ACTION_DOWN) 
	    {
	    	_objectButton.setTextSize(_sizeToExpander);	
	    } 
	    else if (motionEvent.getAction() == MotionEvent.ACTION_UP) 
	    {
	    	_objectButton.setTextSize(_originalSize);
	    }
	    return false;
	  }

	}
