package com.example.game;

import java.util.ArrayList;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;

/**
 * Muestra una lista con las 10 mejores jugadas
 * 
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class FrmBestsPlays extends Activity {
	
	private Button _btnBack;
	
	/**
	 * Implementa el evento OnClick del botn "Volver"
	 * Cambia de la actividad actual a la actividad "Men principal"
	 * @param view
	 */
	public void buttonBackOnClick(View v) 
	{   
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		
    	//Creamos el Intent
        Intent intent = new Intent(FrmBestsPlays.this, FrmMainMenu.class);

        //Iniciamos la nueva actividad
        startActivity(intent);	    			    	

				    	
	}
	
	  @Override
	  protected void onCreate(Bundle savedInstanceState) 
	  {
	        super.onCreate(savedInstanceState);
	        setContentView(R.layout.activity_frm_bests_plays);
	        
	        _btnBack = (Button)findViewById(R.id.btnBestPlaysBack);
	        //Defino el tipo de fuente
	        _btnBack.setTypeface(MyApplication.getTypeFont());
	        
	        
	        ArrayList<String> listBestPlays = getListOfBestPlays();
	        
	        //Si la lista est vaca informo de ello por pantalla
	        if(listBestPlays.size() == 0)
	        	listBestPlays.add("An no hay jugadas almacenadas Juega!");

	        
	        //Adaptador para imprimir la lista con las 10 mejores jugadas
	        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, R.layout.activity_listview, listBestPlays);
  	      
  	        //ListView donde imprimo la lista
	        ListView listView = (ListView) findViewById(R.id.listView_BestPlays);
  	        listView.setAdapter(adapter);
  	             	       
	  }
	  	  
	    
	  /**
	   * Lee de memoria las 10 mejores jugadas almacenadas.
	   * @return ArrayList<String> con las 10 mejores jugadas
	   */
	  private  ArrayList<String> getListOfBestPlays()
	  {
		  
		  boolean bStop = false;
		  int iValueReaded = -1;
		  int i = 1;
		  
		  ArrayList<String> list = new ArrayList<String>();
	    	
	    	while(i<11 && (!bStop))
	    	{
	    		//Leemos un valor de jugada de la memoria
	    		iValueReaded = MyApplication.getSharedPreferencesManager().readIntFromSharedPrefences(String.valueOf(i));
	    		
	    		//Insertamos la puntuacin leda en la lista
	    		if(iValueReaded != -1)
	    			list.add(String.valueOf(iValueReaded));
	    		//No hay ms elementos en la lista, paramos
	    		else
	    			bStop = true;
	    		
	    		i++;
	    	}
	    	
	    	return list;
	    }  
	
	  /**
	 * Borra la lista de las 10 mejores jugadas de memoria.
	 * Esta funcionalidad no es utilizada por el juego, slo por mi, para limpiar la lista para las pruebas. 
	
	  private void removeListBestPlays()
	  {
		  boolean bStop = false;
		  int iValueReaded = -1;
		  int i = 1;
		  
	    	
	    	while(i<11 && (!bStop))
	    	{
	    		iValueReaded = MyApplication.getSharedPreferencesManager().readIntFromSharedPrefences(String.valueOf(i));
	    		
	    		//Si ha ledo algn valor que lo elimine de la lista
	    		if(iValueReaded != -1)
	    			MyApplication.getSharedPreferencesManager().removeEntryToSharedPreferences(String.valueOf(i));
	    		//No hay ms elementos en la lista, paramos
	    		i++;
	    	}
		  
	  }
	  
	   */

}
