package com.example.game;


import android.app.Activity;
import android.os.Bundle;
import android.content.Intent;
import android.view.View;
import android.widget.Button;


/**
 * Muestra el men principal del juego con las diferentes opciones.
 *  
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class FrmMainMenu extends Activity {
	
	

	/**
	 * Implementa el evento OnClick del botn "Iniciar Juego"
	 * Cambia de la actividad actual a la actividad "Niveles disponibles"
	 * @param view
	 */
	public void btnIniciarOnClick(View view) 
	{
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		
		//Creamos el Intent
        Intent intent = new Intent(FrmMainMenu.this, FrmAvailableLevels.class);
        //Inicio la nueva actividad
        startActivity(intent);
	}
	
	/**
	 * Implementa el evento OnClick del botn "Mejores jugadas"
	 * Cambia de la actividad actual a la actividad "Niveles disponibles"
	 * @param view
	 */
    public void btnMejoresJugadasOnClick(View v) 
    {
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
    	
    	//Creamos el Intent
        Intent intent = new Intent(FrmMainMenu.this, FrmBestsPlays.class);

        //Iniciamos la nueva actividad
        startActivity(intent);
    }
   
    
	/**
	 * Implementa el evento OnClick del botn "Configuracin"
	 * Cambia de la actividad actual a la actividad "Niveles disponibles"
	 * @param view
	 */
    public void btnConfiguracionOnClick(View v) 
    {
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
    	
    	//Creamos el Intent
        Intent intent = new Intent(FrmMainMenu.this, FrmSettings.class);

        //Iniciamos la nueva actividad
        startActivity(intent);
     }
 
    
	/**
	 * Implementa el evento OnClick del botn "Ayuda"
	 * Cambia de la actividad actual a la actividad "Niveles disponibles"
	 * @param view
	 */
    public void btnAyudaOnClick(View v) 
    {
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
    	
    	//Creamos el Intent
        Intent intent = new Intent(FrmMainMenu.this, FrmHelp.class);

        //Iniciamos la nueva actividad
        startActivity(intent);
     }
     
	/**
	 * Implementa el evento OnClick del botn "Sobre el juego"
	 * Cambia de la actividad actual a la actividad "Niveles disponibles"
	 * @param view
	 */
    public void btnSobreJuegoOnClick(View v) 
    {
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
    	
    	//Creamos el Intent
        Intent intent = new Intent(FrmMainMenu.this, FrmAboutGame.class);

        //Iniciamos la nueva actividad
        startActivity(intent);
     }
	

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
	    setContentView(R.layout.activity_menu_main);	    
	 	    
	    //Obtengo las referencias a los controles de la interfaz:
        final Button btnIniciar = (Button)findViewById(R.id.btnIniciarJuego);
        //Le asocio al evento "OnTouch" el efecto de expansin
        btnIniciar.setOnTouchListener(new ButtonExpanderOnTouchListener(btnIniciar));
        
        final Button btnMejoresJugadas = (Button)findViewById(R.id.btnMejorJugada);
        btnMejoresJugadas.setOnTouchListener(new ButtonExpanderOnTouchListener(btnMejoresJugadas));
        
        final Button btnConfiguracion = (Button)findViewById(R.id.btnConfiguracion);
        btnConfiguracion.setOnTouchListener(new ButtonExpanderOnTouchListener(btnConfiguracion));
        
        final Button btnAyuda = (Button)findViewById(R.id.btnAyuda);
        btnAyuda.setOnTouchListener(new ButtonExpanderOnTouchListener(btnAyuda));
        
        final Button btnSobreJuego = (Button)findViewById(R.id.btnSobreJuego);
        btnSobreJuego.setOnTouchListener(new ButtonExpanderOnTouchListener(btnSobreJuego));
        
        
        //La asigno la fuente a los botones del men:
        btnIniciar.setTypeface(MyApplication.getTypeFont());
        btnMejoresJugadas.setTypeface(MyApplication.getTypeFont());
        btnConfiguracion.setTypeface(MyApplication.getTypeFont());
        btnAyuda.setTypeface(MyApplication.getTypeFont());
        btnSobreJuego.setTypeface(MyApplication.getTypeFont());
        
	}
	
    protected void onStart() {
        super.onStart();
        // The activity is about to become visible.
      
    }
    

}
