package com.example.game;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;


/**
 * Muestra las opciones de configuracin del juego.
 * Activar o desactivar los sonidos de efectos y ambiental.
 *
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class FrmSettings extends Activity {
	
	
	private Button _btnSoundEffects;
	private Button _btnSoundEnvironment;
	private Button _btnBack;
	
	
	
	/**
	 * Implementa el evento OnClick del botn "Sonidos de efectos"
	 * Activa o desactiva los sonidos de efectos
	 * @param view
	 */
	public void buttonSoundEffectsOnClick(View v) 
	{   
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		    			    	
		//Si el sonido est activado, lo desactivamos
		if(MyApplication.getSoundEffects())
		{
			MyApplication.setSoundEffects(false);
			//Cambio el aspecto del boton SoundEffects
		    _btnSoundEffects.setText("Off");
		}
		//Si est desactivado lo activamos
		else
		{
			MyApplication.setSoundEffects(true);
		    //Cambio el aspecto del boton SoundEffects
		    _btnSoundEffects.setText("On");
		}
		    	
	}	
	
	
	/**
	 * Implementa el evento OnClick del botn "Sonido de ambiente"
	 * Activa o desactiva el sonido de ambiente
	 * @param view
	 */
	public void buttonSoundEnvironmentOnClick(View v) 
	{   
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);	 
		
		//Si el sonido est activado, lo desactivamos
		if(MyApplication.getSoundEnvironment())
		{
			MyApplication.setSoundEnvironment(false);
			//Cambio el aspecto del boton SoundEffects
			_btnSoundEnvironment.setText("Off");
		}
		//Si est desactivado lo activamos
		else
		{
			MyApplication.setSoundEnvironment(true);
			//Cambio el aspecto del boton SoundEffects
			_btnSoundEnvironment.setText("On");
		}
			    	
	 }
		
			
	/**
	 * Implementa el evento OnClick del botn "Volver"
	 * Cambia de la actividad actual a la actividad "Men principal"
	 * @param view
	 */
	public void buttonBackOnClick(View v) 
	{   
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		
    	//Creamos el Intent
        Intent intent = new Intent(FrmSettings.this, FrmMainMenu.class);

        //Iniciamos la nueva actividad
        startActivity(intent);	    			    					    	
	}
			
	
	  @Override
	    protected void onCreate(Bundle savedInstanceState) 
	  {
	        super.onCreate(savedInstanceState);
	        //setContentView(R.layout.ventanajuego);
	        setContentView(R.layout.activity_frm_settings);
	        
	        
	        //Obtengo las referencias a los elementos visuales:
	        final TextView txSoundEffects = (TextView)findViewById(R.id.txvSoundEffects);
	        final TextView txSoundEnvironment = (TextView)findViewById(R.id.txvSoundEnvironment);
	        _btnSoundEffects = (Button)findViewById(R.id.btnSoundEffects);
	        _btnSoundEnvironment = (Button)findViewById(R.id.btnSoundEnvironment);
	        _btnBack = (Button)findViewById(R.id.btnSettingBack);
	        
	        
	        //Defino el tipo de fuente
	        txSoundEffects.setTypeface(MyApplication.getTypeFont());
	        txSoundEnvironment.setTypeface(MyApplication.getTypeFont());
	        _btnSoundEffects.setTypeface(MyApplication.getTypeFont());
	        _btnSoundEnvironment.setTypeface(MyApplication.getTypeFont());
	        _btnBack.setTypeface(MyApplication.getTypeFont());
	        
	        //Leo la configuracin actual y lo muestro en los controles
			if(MyApplication.getSoundEffects())
			    _btnSoundEffects.setText("On");
			else
				_btnSoundEffects.setText("Off");
			
			if(MyApplication.getSoundEnvironment())
				_btnSoundEnvironment.setText("On");
			else
				_btnSoundEnvironment.setText("Off");			
	        
	    }
}