package com.example.game;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;



/**
 * Muestra la pantalla del videojuego, con el HUD, los agentes letras y los controles de interaccin.
 * 
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
public class FrmStartGame extends Activity {
	
	
	private TextView _txtNumAgentes;
	private TextView _txtDisplay;
	private TextView _txtPoints;
	private TextView _txtNextAgent;
	private TextView _txtTime;
	private TextView _txVLevel;
	private TextView _txtFinishedLevel;
    private TextView _txViewPoints;
    private TextView _txViewLettersLeft;
    private TextView _txViewTotalPoints;
    private TextView _txViewPointsValue;
    private TextView _txViewLettersLeftValue;
    private TextView _txViewTotalPointsValue;
    
	private TextView _txtLabelNumAgentes;
	private TextView _txtLabelPoints;
	private TextView _txtLabelNextAgent;
	private TextView _txtLabelTime;
	private TextView _txVLabelLevel;
    
	private TextView _txViewNewLevel;
	
	private Button _btnPause;
	private Button _btnAcelerar;
	
	private Button _btnPauseSalir;
	private Button _btnPauseContinuar;
	
	private GameView _pScreenGame;
	private GameLoopThread _pGameLoopThread;
	
	private boolean _isPaused = false;
	
	
	
	/**
	 * Metodo Onclick para el botn "Pause". Pausa la partida y muestra un men emergente con las opciones: Continuar o Salir.
	 * 
	 * @param v
	 */
	public void buttonPauseOnClick(View v) 
	{   	
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		
		//Si no est pausado
		if(!_isPaused)
		{
			_isPaused = true;
		    //Pauso msica de fondo
		    MyApplication.getSoundManager().pausePlayer();
		    //Cambio el aspecto del boton de pause
		    _btnPause.setBackgroundResource(R.drawable.button_green_pause);
		    disablePauseControls();
		    
		    //Muestro los botones asociados al botn Pause
		    showPauseButtons();
		    
		    _pGameLoopThread.updateScreen();
		 }
		 //Caso de estar pausado
		 else
		 {
			 _isPaused = false;
		     //Reanudo msica de fondo
			 MyApplication.getSoundManager().startPlayer();
		     //Cambio el aspecto del boton de pause
		     _btnPause.setBackgroundResource(R.drawable.button_pause_off);
		     enablePauseControls();
		     
			 //Oculto los botones asociados al botn Pause
			 hidePauseButtons();
		  }
		    	
	 }
	
		
	/**
	 * Metodo Onclick para el botn "Acelerar". Crea a un nuevo agente
	 * 
	 * @param v
	 */
	public void buttonAcelerarOnClick(View v) 
	{  
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Boing);
		_pScreenGame.createAgent();
	}
		
			
	/**
	 * Metodo Onclick para el textView "Display". Si la palabra actual es vlida en la lengua inglesa, la valida, eliminando los
	 * agentes letras correspondientes y sumando los puntos que procedan. Si la palabra actual no es vlida, la borra.
	 */
	private OnClickListener txVDisplayListener = new OnClickListener() {
	    public void onClick(View v) {
	     
	    	_pScreenGame.checkWord();
	    	
	    }
	};
	
	
	/**
	 * Metodo Onclick para el botn "Continuar" asociado al botn "Pause". Reanuda la partida.
	 * 
	 * @param v
	 */
	public void btnPauseContinuarOnClick(View v) 
	{  
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
		
		_isPaused = false;
	     //Reanudo msica de fondo
		 MyApplication.getSoundManager().startPlayer();
	     //Cambio el aspecto del boton de pause
	     _btnPause.setBackgroundResource(R.drawable.button_pause_off);
	     enablePauseControls();
	     
		 //Oculto los botones asociados al botn Pause
		 hidePauseButtons();
	}
		

	/**
	 * Metodo Onclick para el botn "Salir" asociado al botn "Pause". Abandona la partida actual y regresa al men principal
	 * 
	 * @param v
	 */
	public void btnPauseSalirOnClick(View v) 
	{  
        //Reproduzco sonido click
		MyApplication.getSoundManager().playSound(MyApplication.Sounds.Click);
    	
    	//Creamos el Intent
        Intent intent = new Intent(FrmStartGame.this, FrmMainMenu.class);

        //Iniciamos la nueva actividad
        startActivity(intent);

	}
		
	
	@Override
	    protected void onCreate(Bundle savedInstanceState) {
	        super.onCreate(savedInstanceState);        
	        setContentView(R.layout.activity_frm_start_game);
	                
	        //Obtengo referencias a los controles vistas:
	        _txtNumAgentes = (TextView) findViewById(R.id.txtVNumeroAgentes);
	        _txVLevel = (TextView) findViewById(R.id.txtNivel);
	        _txtPoints = (TextView) findViewById(R.id.txtVPuntos);
	        _txtNextAgent = (TextView) findViewById(R.id.txtVProximoAgente);
	        _txtTime = (TextView) findViewById(R.id.txtVTiempo);
	        
	        
	        _txtLabelNumAgentes = (TextView) findViewById(R.id.txtVLabelProximoAgente);
	        _txVLabelLevel = (TextView) findViewById(R.id.txtLabelNivel);
	        _txtLabelPoints = (TextView) findViewById(R.id.txtVLabelPuntos);
	        _txtLabelNextAgent = (TextView) findViewById(R.id.txtVLabelNumeroAgente);
	        _txtLabelTime = (TextView) findViewById(R.id.txtVLabelTiempo);
	        
	        _txtDisplay = (TextView) findViewById(R.id.txtDisplay);
	        _txtDisplay.setOnClickListener(txVDisplayListener);
	        
	        _txViewNewLevel= (TextView) findViewById(R.id.txViewNewLevel);
	        _txViewNewLevel.setTypeface(MyApplication.getTypeFont());
	        
	        _txtFinishedLevel = (TextView) findViewById(R.id.txViewFinishedLevel);
	        _txtFinishedLevel.setTypeface(MyApplication.getTypeFont());
	        
	        _txViewPoints = (TextView) findViewById(R.id.txViewPoints);
	        _txViewPoints.setTypeface(MyApplication.getTypeFont());
	        
	        _txViewLettersLeft= (TextView) findViewById(R.id.txViewLettersLeft);
	        _txViewLettersLeft.setTypeface(MyApplication.getTypeFont());
	        
	        _txViewTotalPoints= (TextView) findViewById(R.id.txViewTotalPoints);
	        _txViewTotalPoints.setTypeface(MyApplication.getTypeFont());
	        
	        _txViewPointsValue = (TextView) findViewById(R.id.txViewPointsValue);
	        _txViewPointsValue.setTypeface(MyApplication.getTypeFont());	        
	        
	        _txViewLettersLeftValue= (TextView) findViewById(R.id.txViewLettersLeftValue);
	        _txViewLettersLeftValue.setTypeface(MyApplication.getTypeFont());
	                
	        
	        _txViewTotalPointsValue= (TextView) findViewById(R.id.txViewTotalPointsValue);
	        _txViewTotalPointsValue.setTypeface(MyApplication.getTypeFont());
	        
	        
	        //Inicializo el valor de los TextView
	        _txtNumAgentes.setText("0");
	        _txtPoints.setText("0");
	        _txtTime.setText("0");
	        _txViewPointsValue.setText("0");
	        _txViewLettersLeftValue.setText("0");
	        _txViewTotalPointsValue.setText("0");
	        
	        
	        //El nivel lo determinamos en una ventana anterior, es un parmetro que debemos saber aqu
	        //Imprimo en la pantalla el nivel del juego
	        _txVLevel.setText(String.valueOf(MyApplication.getCurrentLevel()));        
	        
	        //Obtengo referencia a la instancia de la clase GameView
	        _pScreenGame = (GameView) findViewById(R.id.SurfaceView01);	 
	        
	        //Obtengo una referencia al hilo de ejecucin
	        _pGameLoopThread = _pScreenGame.getGameLoopThread();
		        
	       _btnPause = (Button)findViewById(R.id.btnPause);
	       //Establezco su imagen inicial, no pausado
	       _btnPause.setBackgroundResource(R.drawable.button_pause_off);
	       
	       
	       _btnAcelerar = (Button)findViewById(R.id.btnAcelerar);
	       //Establezco la imagen del botn acelerar
	       _btnAcelerar.setBackgroundResource(R.drawable.button_accelerate);
	       //Cambia el aspecto del botn cuando hacemos touch sobre l
	       _btnAcelerar.setOnTouchListener(new ButtonHighlighterOnTouchListener(_btnAcelerar));   
	       
	       
	       _btnPauseContinuar = (Button)findViewById(R.id.buttonPauseContinue);
	       _btnPauseContinuar.setOnTouchListener(new ButtonExpanderOnTouchListener(_btnPauseContinuar));
	       _btnPauseContinuar.setTypeface(MyApplication.getTypeFont()); 
	       
	       
	       _btnPauseSalir = (Button)findViewById(R.id.buttonPauseExit);
	       _btnPauseSalir.setOnTouchListener(new ButtonExpanderOnTouchListener(_btnPauseSalir));
	       _btnPauseSalir.setTypeface(MyApplication.getTypeFont()); 	       
	       
	       //Hago invisible los TextView informativos
	       setTextViewInvisible();
	       
	       //Oculto el HUD
	       hideHUD();
	       
	       //Oculto los botones asociados al botn Pause
	       hidePauseButtons();
	       
	    }

	  
	    protected void onStart() {
	       
	        	super.onStart();
	        	// The activity is about to become visible.    
	    }
	    
	    
	    @Override
	    protected void onResume() {
	        super.onResume();
	        // The activity has become visible (it is now "resumed").
	    }
	    
	    @Override
	    protected void onPause() {
	    	super.onPause();
		    // Another activity is taking focus (this activity is about to be "paused").
		    
		    	
		    /* Compruebo si GameLoopThread est durmiendo, en tal caso, despertarlo.
		    * Al llegar al final del juego reproduzco una cancin de 75 seg, puede que el usuario en el proceso de reproduccin aborte la
		    * cancin, en tal caso, el hilo estara durmiendo. Identifico esta situacin y despierto al hilo para que pueda finalizar.
		    */ 
		    if(_pGameLoopThread.isSleeping())
		    	_pGameLoopThread.interrupt();
		    
		    finish();
		    
	    }
	    
	    
	    @Override
	    protected void onStop() {
		    super.onStop();
		    // The activity is no longer visible (it is now "stopped")
		        
		    //Si el sonido ambiente est activado compruebo si algn reproductor est sonando, en tal caso, pararlo
	        if(MyApplication.getSoundEnvironment())
	        	MyApplication.getSoundManager().checkPlayers();   	
	        	
	    }
	    
	    
	    @Override
	    protected void onDestroy() {
	    super.onDestroy();
	    	// The activity is about to be destroyed.
	    }
	    
	  
	  
	    //Devuelve la altura del botn acelerar, que coincide con la altura del botn pausa.
	    //La altura del display es inferior a dicha altura.
	    public int setParametersScreen()
	    {
	    	return _btnAcelerar.getHeight(); 
	    }
	    
	    public void setTextViewNumAgent(final String numAgents){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	 _txtNumAgentes.setText(numAgents); 
		        } 
		     });
		}
	 
	  
	  public void setTextViewDisplay(final String contentDisplay){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtDisplay.setText(contentDisplay); 
		        } 
		     });
		}
	  
	  public void setTextViewPoints(final String points){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtPoints.setText(points);     
		        } 
		     });
		}
	  
	  public void setTextViewNextAgent(final String nextAgent){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtNextAgent.setText(nextAgent);     
		        } 
		     });
		}
	  
	  public void setTextViewTime(final String time){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtTime.setText(time);     
		        } 
		     });
		}
	  
	  public void setViewDisplayColorGreen(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtDisplay.setBackgroundColor(Color.rgb(50, 199, 46));    
		        } 
		     });
		}

	  public void setViewDisplayColorRed(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtDisplay.setBackgroundColor(Color.rgb(221, 0, 0));    
		        } 
		     });
		}
	  
	  public void setTextViewLevel(final String level){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	 _txVLevel.setText(level);   
		        } 
		     });
		}
	  
	  public void setTextViewVisibleFinishedLevel(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtFinishedLevel.setVisibility(TextView.VISIBLE);     
		        } 
		     });
		}
	  
	  public void setTextViewFinishedLevel(final String value){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtFinishedLevel.setText(value);  
		        } 
		     });
		}
	    
	  public void setTextViewPointsValue(final String value){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewPointsValue.setText(value);   
		        } 
		     });
		}
	  
	  public void setTextViewLettersLeftValue(final String value){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewLettersLeftValue.setText(value);  
		        } 
		     });
		}
	  
	  public void setTextViewTotalPointsValue(final String value){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewTotalPointsValue.setText(value);   
		        } 
		     });
		}
	  
	  public void setTextViewNewLevel(final String value){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewNewLevel.setText("Nivel " + value);   
		        } 
		     });
		}
	  
	  public void setTextViewInvisible(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtFinishedLevel.setVisibility(TextView.INVISIBLE);
			        _txViewPoints.setVisibility(TextView.INVISIBLE);		        
			        _txViewLettersLeft.setVisibility(TextView.INVISIBLE);
			        _txViewTotalPoints.setVisibility(TextView.INVISIBLE);
			        _txViewPointsValue.setVisibility(TextView.INVISIBLE);		        
			        _txViewLettersLeftValue.setVisibility(TextView.INVISIBLE);
			        _txViewTotalPointsValue.setVisibility(TextView.INVISIBLE);
		        } 
		     });
		}
	  
	  public void setTextViewVisible(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtFinishedLevel.setVisibility(TextView.VISIBLE);     
			        _txViewPoints.setVisibility(TextView.VISIBLE);		        
			        _txViewLettersLeft.setVisibility(TextView.VISIBLE);
			        _txViewTotalPoints.setVisibility(TextView.VISIBLE);
			        _txViewPointsValue.setVisibility(TextView.VISIBLE);		        
			        _txViewLettersLeftValue.setVisibility(TextView.VISIBLE);
			        _txViewTotalPointsValue.setVisibility(TextView.VISIBLE);
		        } 
		     });
		}
	  
	  public void hideHUD(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtNumAgentes.setVisibility(TextView.INVISIBLE);
		        	_txVLevel.setVisibility(TextView.INVISIBLE);		        
		        	_txtPoints.setVisibility(TextView.INVISIBLE);
		        	_txtNextAgent.setVisibility(TextView.INVISIBLE);
		        	_txtTime.setVisibility(TextView.INVISIBLE);	
		        	
		        	_txtLabelNumAgentes.setVisibility(TextView.INVISIBLE);
		        	_txVLabelLevel.setVisibility(TextView.INVISIBLE);		        
		        	_txtLabelPoints.setVisibility(TextView.INVISIBLE);
		        	_txtLabelNextAgent.setVisibility(TextView.INVISIBLE);
		        	_txtLabelTime.setVisibility(TextView.INVISIBLE);	
		        } 
		     });
		}
	  
	  public void hidePauseButtons(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		 	       _btnPauseSalir.setVisibility(Button.INVISIBLE);
			       _btnPauseContinuar.setVisibility(Button.INVISIBLE);	
		        } 
		     });
		}
	  
	  public void showPauseButtons(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		 	       _btnPauseSalir.setVisibility(Button.VISIBLE);
			       _btnPauseContinuar.setVisibility(Button.VISIBLE);	
		        } 
		     });
		}
	  
	  public void showHUD(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txtNumAgentes.setVisibility(TextView.VISIBLE);
		        	_txVLevel.setVisibility(TextView.VISIBLE);		        
		        	_txtPoints.setVisibility(TextView.VISIBLE);
		        	_txtNextAgent.setVisibility(TextView.VISIBLE);
		        	_txtTime.setVisibility(TextView.VISIBLE);	
		        	
		        	_txtLabelNumAgentes.setVisibility(TextView.VISIBLE);
		        	_txVLabelLevel.setVisibility(TextView.VISIBLE);		        
		        	_txtLabelPoints.setVisibility(TextView.VISIBLE);
		        	_txtLabelNextAgent.setVisibility(TextView.VISIBLE);
		        	_txtLabelTime.setVisibility(TextView.VISIBLE);
		        } 
		     });
		}
	  
	  public void setTextViewVisiblePoints(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {             
			        _txViewPoints.setVisibility(TextView.VISIBLE);
			        _txViewPointsValue.setVisibility(TextView.VISIBLE);	
		        } 
		     });
		}
	  
	  public void setTextViewVisibleLettersLeft(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewLettersLeft.setVisibility(TextView.VISIBLE);  
		        	_txViewLettersLeftValue.setVisibility(TextView.VISIBLE); 
		        } 
		     });
		}
	  
	  public void setTextViewVisibleTotalPoints(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {             
		        	_txViewTotalPoints.setVisibility(TextView.VISIBLE);
			        _txViewTotalPointsValue.setVisibility(TextView.VISIBLE);	
		        } 
		     });
		}
	  
	  public void setTextViewVisibleNewLevel(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewNewLevel.setVisibility(TextView.VISIBLE);     
		        } 
		     });
		}
	  
	  
	  public void setTextViewInvisibleNewLevel(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		        	_txViewNewLevel.setVisibility(TextView.INVISIBLE);     
		        } 
		     });
		}
	  
	  public boolean isPausedGame()
	  {
		  return _isPaused;
	  
	  }
	  
	  
	  /**
	 * Habilita los controles de interaccin
	 */
	private void enablePauseControls()
	  {
		  _btnAcelerar.setEnabled(true);
		  _txtDisplay.setEnabled(true); 
	  }
	  
	  
	
	  /**
	 * Desabilita los controles de interaccin
	 */
	private void disablePauseControls()
	  {
		  _btnAcelerar.setEnabled(false);
		  _txtDisplay.setEnabled(false); 
	  }
	  
		
	/**
	 * Habilita los controles de interaccin 
	 */
	public void enableControls(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		  		  _btnAcelerar.setEnabled(true);
				  _txtDisplay.setEnabled(true); 
				  _btnPause.setEnabled(true);     
		        } 
		     });
		}
	
	  
	 /**
	 * Inhabilita los controles de interaccin
	 */
	public void disableControls(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {         
		  		  _btnAcelerar.setEnabled(false);
				  _txtDisplay.setEnabled(false); 
				  _btnPause.setEnabled(false);   
		        } 
		     });
		}
	  
	/**
	* Mtodo para volver al men pricipal
	*/
	public void backToMainMenuScreen(){
		    this.runOnUiThread(new Runnable() {     
		        public void run() {  
		        	//Creamos el Intent
		        	Intent intent = new Intent(FrmStartGame.this, FrmMainMenu.class);

		        	//Iniciamos la nueva actividad
		        	startActivity(intent);	   
		        } 
		     });
		}
}
