package com.example.game;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Timer;
import java.util.TimerTask;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.content.Intent;
import android.graphics.Typeface;


/**
 * Actividad donde inicia la ejecucin del juego.
 *
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class MainActivity extends Activity {
	
	private static final String Tag = MainActivity.class.getSimpleName();
	
	//Variable para controlar cuando lanzo la carga de las palabras de la gramtica inglesa.
	private boolean bLaunchedLoad;


	/**
	 * Punto de inicio de ejecucin del juego 
	 */
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
	    setContentView(R.layout.activity_main);
	      
	   
	    SoundManager oSoundManager = new SoundManager();
	    
	    oSoundManager.init(getBaseContext());
	    //Cargo los sonidos de efectos que utilizar en el juego
	    oSoundManager.addSound(0, R.raw.boing);
	    oSoundManager.addSound(1, R.raw.click);
	    oSoundManager.addSound(2, R.raw.coins);
	    oSoundManager.addSound(3, R.raw.eraser);
	    oSoundManager.addSound(4, R.raw.kid_laugh);
	    oSoundManager.addSound(5, R.raw.goat);
	    oSoundManager.addSound(6, R.raw.peop);
	    oSoundManager.addSound(7, R.raw.applause);
	    
	    //Paso la referencia a la instancia de la clase que gestiona los sonidos a "MyApplication", sta la almacena como una referencia 
	    //esttica accesible desde cualquier clase
	    MyApplication.setSoundManager(oSoundManager);
	    
	    //Por defecto activo los sonidos
	    MyApplication.setSoundEffects(true);
	    MyApplication.setSoundEnvironment(true);
	 	
               
        //Defino el tipo de fuente
        Typeface typeFace =  Typeface.createFromAsset(getAssets(),"fonts/fontText.ttf");
        
	    //Paso el tipo de fuente a "MyApplication", sta la almacena como una referencia esttica accesible desde cualquier clase
	    MyApplication.setTypeFont(typeFace);    
	    
	    //Instancio la clase ManagerSharedPreferences para trabajar con la informacin que persiste la aplicacin
	    SharedPreferencesManager objectSharedPreferencesManager = new SharedPreferencesManager(this);
	    //Almaceno una referencia a la instancia en MyApplication
	    MyApplication.setSharedPreferencesManager(objectSharedPreferencesManager);	   
	    
	    //Instancio la clase ManagerCollision para controlar las colisiones entre agentes
	    ManagerCollision managerCollision = new ManagerCollision();
	    //Almaceno una referencia a la instancia en MyApplication
	    MyApplication.setManagerCollision(managerCollision);	   
	    
	    
	    //Digo que an no estn cargadas las palabras de la gramtica inglesa
	    MyApplication.setIsLoadedEnglishGrammarWords(false);
	    
	    //Digo que tampoco he lanzado la carga de las palabras
	    bLaunchedLoad = false;
	    
	    //Almaceno la densidad de la pantalla del dispositivo actual donde ejecute el juego
	    MyApplication.setDensityScreen(getResources().getDisplayMetrics().density);
	    
	    
	    //Programo una tarea con la cual lanzo la carga de las palabras de la gramatica inglesa a memoria y cada segundo
	    //Compruebo si la carga ha finalizado, en tal caso, mando la orden de pasar a la siguiente actividad
        Timer timer = new Timer();
        timer.scheduleAtFixedRate(taskToLoadEnglishGrammarWords, 1000, 1000);
	       	    
	}
	
	
    protected void onStart() {
        super.onStart();
        // The activity is about to become visible.
    }

    @Override
    protected void onResume() {
        super.onResume();
        // The activity has become visible (it is now "resumed").
       
        //No tiene sentido estar en esta actividad con las palabras cargadas a memoria, mando a ir a la actividad men
        if(MyApplication.getIsLoadedEnglishGrammarWords())
        	//Mostramos el men principal
	    	showMainMenu();	
        	     
    }
    


	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
    
	
	/**
	 * Tarea invocada cada segundo, lanza la carga de las palabras de la gramtica inglesa a memoria la primera vez que se ejecute.
	 * Y comprueba para las restantes si la carga ha finalizado. Una vez finalizada, pasa a la siguiente actividad.
	 */
	private TimerTask taskToLoadEnglishGrammarWords = new TimerTask() 
	{   
		@Override
	    public void run() 
	    {   
	        //Si las palabras no estn cargadas ni ha sido lanzada su carga
			if(!bLaunchedLoad && !MyApplication.getIsLoadedEnglishGrammarWords() )
	        {
	        	//Indico que he lanzado la carga
				bLaunchedLoad = true;
	        	
	        	//Cargo las palabras de la gramtica inglesa a memoria
	        	loadEnglishGrammarWords();
	        	
	        	//Indico que las palabras han sido cargadas
	        	MyApplication.setIsLoadedEnglishGrammarWords(true);
	        }
			//Si las palabras estn cargadas
	        else if(MyApplication.getIsLoadedEnglishGrammarWords())
	        {
	        	//Desactivo el timer
	        	this.cancel();
	        	
	        	//Mostramos el men principal
	    	    showMainMenu();
	    	    
	        }  
	    }
	};
	
	
    /**
     * Carga desde el fichero de texto las palabras vlidas de la gramatica inglesa, insertndolas en la estructura ArrayList
     */
    private void loadEnglishGrammarWords()
    {
    	ArrayList<String> englishGrammarWords = new ArrayList<String>();
       	
     	try 
	   	{  	   		
     		//Abro el fichero 
   		 	BufferedReader in = new BufferedReader(new InputStreamReader(this.getAssets().open("EnglishGrammarWords.txt")));
	        String line = in.readLine();
	        //Leo el contenido del fichero, insertando las palabras en el ArrayList
	        while(line != null) 
	        {
	        	englishGrammarWords.add(line);
	            line = in.readLine();
	        }
	        in.close();
	    } 
     	catch(FileNotFoundException fnfe) 
	    {
     		Log.e(Tag, "Fichero no encontrado EnglishGrammarWords.txt. " + fnfe.getMessage());
	    } 
     	catch(IOException ioe) 
	    {
     		Log.e(Tag, "Error de lectura en fichero EnglishGrammarWords.txt. " + ioe.getMessage());
	    } 
     	
     	MyApplication.setEnglishGrammarWords(englishGrammarWords);
    }

	
    /**
     * Cambia de sta actividad a la actividad que visualiza el men principal 
     */
    private void showMainMenu() 
	{
        //Creamos el Intent
        Intent intent = new Intent(MainActivity.this, FrmMainMenu.class);
        
        //Iniciamos la nueva actividad
        startActivity(intent);
	}
	
}
