package com.example.game;


/**
 * Clase para gestionar las colisiones entre agentes.
 * 
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class ManagerCollision {
	

	//Tabla para registrar las 50 ltimas colisiones
	private DataCollision  [] _listCollisions;
	
	//Para contabilizar el nmero de colisiones totales
	private int _numCollision;
	
	//Almacena el tiempo mnimo que debe transcurrir desde la ltima colisin (para dos mismos agentes. Es decir,
	//dos agentes determinados colisionaron en un pasado, y esos dos mismos agentes vuelven a colisionar)
	//para que pueda ser considerada como vlida.
	private int _timeLastCollision;
	
	/**
	 * Inicializa los valores, y crea una tabla para almacenar las 50 ltimas colisiones.
	 */
	public ManagerCollision()
	{
		_listCollisions = new DataCollision[50];
		_numCollision = 0;
		_timeLastCollision = 0;
	}
	
	
	
	/**
	 * Determina el tiempo mnimo (en milisegundos) que debe transcurrir entre dos colisiones
	 *  producidas por los mismos agentes. Para un nivel determinado.
	 * @param currentLevel: nivel actual.
	 */
	public void setTimeLastCollision(int currentLevel)
	{	
		switch(currentLevel)
		{
	        case 1: _timeLastCollision = 2500;
	        		break;
	        		
	        case 2: _timeLastCollision = 2250;
			        break;
			        
			case 3: _timeLastCollision = 2000;        			
			        break;
			        
			case 4: _timeLastCollision = 1750;         			
	        		break;
			       
			case 5: _timeLastCollision = 1500;
    				break;
    				
			case 6: _timeLastCollision = 1250;
					break;	
				
			case 7: _timeLastCollision = 1000;
					break;
			
			case 8: _timeLastCollision = 750;
					break;
					
			case 9: _timeLastCollision = 500;
					break;
					
			case 10: _timeLastCollision = 250; 
					 break;
					
			default: 
			        break;
		
		}	
	}
	

	/**
	 * 	Registra una colisin en la tabla de colisiones
	 * @param posMain: posicin del agente principal dentro de la lista de agentes.
	 * @param posSecondary: posicin del agente secundario dentro de la lista de agentes.
	 * @param timeCollision: instante en el cual ocurri la colisin.
	 */
	public void setNewCollision(int posMain, int posSecondary, long timeCollision) 
	{
		DataCollision dataCollision = new DataCollision(posMain, posSecondary, timeCollision);
		
		//Mantengo una tabla con las 50 ltimas colisiones
		int posCollision = _numCollision % 50;
		
		//Inseto la nueva colisin en la posicin que le corresponda
		_listCollisions[posCollision] = dataCollision;
		
		//Contabilizo el nmero de colisiones
		_numCollision++;
	}	
	
	
	//
	/**
	 * Comprueba que sea una colisin permitida: que no est entre las 50 ltimas y si est que haya transcurrido el tiempo mnimo 
	 * permitido entre colisiones
	 * @param posMain: posicin del agente principal dentro de la lista de agentes.
	 * @param posSecondary: posicin del agente secundario dentro de la lista de agentes.
	 * @param timeCollision: instante en el cual ocurri la colisin.
	 * @return true si la colisin es vlida, false en caso contrario.
	 */
	public boolean isValidateCollision(int posMain, int posSecondary, long timeCollision) 
	{
		boolean isValidate = true;
		
		//Miro en la table de colisiones
		for(int i = 0; i < 50; i++ )
		{
			DataCollision dataCollision  = _listCollisions[i];
			
			//Si hay elementos en la posicin indicada
			if(dataCollision != null)
			{
				//Los agentes que colisionan parecen ser los mismos
				if((posMain == dataCollision.getPositionMain()) && (posSecondary == dataCollision.getPositionSecondary()))
				{
					//Compruebo si ha transcurrido el tiempo mnimo permitido
					if( (timeCollision - dataCollision.getTimeCollision()) < _timeLastCollision)
						//No ha transcurrido el tiempo mnimo permitido desde su ltima colisin, entonces es invalida
						isValidate = false;
				}
			}
			else
				break;
		}
		
		return isValidate;
		
	}
}


