package com.example.game;

import java.util.ArrayList;

import android.app.Application;
import android.graphics.Typeface;

/**
 * Clase donde almanceno referencias a instancias de otras clases o recursos, para que estn disponibles durante toda la 
 * ejecucin del juego y desde cualquier lugar.
 *  
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
public class MyApplication extends Application {
	
	private static SoundManager _soundManager;
    private static Typeface _typeFont;
    private static Boolean _isOnSoundEffects;
    private static Boolean _isOnSoundEnvironment;
    private static SharedPreferencesManager _objectSharedPreferencesManager;
    private static ArrayList<String> _englishGrammarWords;
	private static ManagerCollision _managerCollision;
    
    //Almacena la densidad de la pantalla, lti para covertir los pixeles en la pantalla del dispositivo a la unidad sp.
    private static float _densityScreen;
    
    //Para saber si las palabras de la gramtica inglesa han sido cargadas a memoria
    private static Boolean _isLoadedEnglishGrammarWords;
   
    //Nivel mximo habilitado
    private static int _levelMaxAvailable;
    
    //Nivel de inicio seleccionado
    private static int _currentLevel;
    

    public static SoundManager getSoundManager() {
        return _soundManager;
    }

    public static void setSoundManager(SoundManager soundManagerIns) {
        _soundManager = soundManagerIns;
    }
    
    public static Typeface getTypeFont() {
        return _typeFont;
    }

    public static void setTypeFont(Typeface typeFont) {
        _typeFont = typeFont;
    }
     
    public static Boolean getSoundEffects() {
        return _isOnSoundEffects;
    }

    public static void setSoundEffects(Boolean isOnSoundEffects) {
    	_isOnSoundEffects = isOnSoundEffects;
    }
    
    public static Boolean getSoundEnvironment() {
        return _isOnSoundEnvironment;
    }

    public static void setSoundEnvironment(Boolean isOnSoundEnvironment) {
    	_isOnSoundEnvironment = isOnSoundEnvironment;
    }
        
    public static int getLevelMaxAvailable() {
        return _levelMaxAvailable;
    }

    public static void setLevelMaxAvailable(int levelMaxAvailable) {
    	_levelMaxAvailable = levelMaxAvailable;
    }
    
    public static int getCurrentLevel() {
        return _currentLevel;
    }

    public static void setCurrentLevel(int currentLevel) {
    	_currentLevel = currentLevel;
    }
    
    
    public static SharedPreferencesManager getSharedPreferencesManager() {
        return _objectSharedPreferencesManager;
    }

    public static void setSharedPreferencesManager(SharedPreferencesManager objectSharedPreferencesManager) {
    	_objectSharedPreferencesManager = objectSharedPreferencesManager;
    }
    
    
    public static ArrayList<String>  getEnglishGrammarWords() {
        return _englishGrammarWords;
    }

    public static void setEnglishGrammarWords(ArrayList<String> englishGrammarWords) {
    	_englishGrammarWords = englishGrammarWords;
    }
    
    public static void setIsLoadedEnglishGrammarWords(Boolean isLoadedEnglishGrammarWords) {
    	_isLoadedEnglishGrammarWords = isLoadedEnglishGrammarWords;
    }
    
    public static Boolean getIsLoadedEnglishGrammarWords() {
        return _isLoadedEnglishGrammarWords;
    }
    
    
    public static void setDensityScreen(float densityScreen) {
    	_densityScreen = densityScreen;
    }
    
    public static float getDensityScreen() {
        return _densityScreen;
    }
    
    public static ManagerCollision getManagerCollision() {
        return _managerCollision;
    }

    public static void setManagerCollision(ManagerCollision managerCollision) {
    	_managerCollision = managerCollision;
    }
    
    
    /**
     * @author Antonio Javier Garrido Rodrguez
     * 
     * Clase donde almaceno valores de configuracin del juego.
     * Y provee de mtodos que devuelven informacin de configuracin.
     *
     */
    public static class Config {
    	
    	//Valor que indica el nmero de niveles del juego
    	public static final int NumLevel = 10;
    	//Valor que tomo como referencia para calcular cada cuanto tiempo crear un agente, en funcin al nivel.
    	public static final int TimeMakeAgent = 400;

    	/**
    	 * Determina en funcin al nivel cual es el nmero de agentes permitidos en pantalla.
    	 * @param level: nivel actual.
    	 * @return entero con el nmero de agentes permitidos en pantalla. Sera el valor devuelto menos uno.
    	 */
    	public static int getNumAgentToLost(int level)
    	{
    		int numAgent = 0;
    		
    		if(level < 6)
    			numAgent = 26;
    		else
    			numAgent = 51;
    		
    		return numAgent;
    		
    	}
    	
    	/**
    	 * Determina cada cuantos milisegundos debe crear a un agente en funcin al nivel.
    	 * @param level: nivel actual.
    	 * @return entero que indica cada cuantos milisegundos debe crear a un agente.
    	 */
    	public static int getTimeMakeAgent(int level)
    	{
    		int iTimeMakeAgent = 0;
    		
        	//Clculo dependiendo del nivel cada cuantos milisegundos debe crear a un agente
        	if(level < 7)
        		iTimeMakeAgent = (NumLevel - level) * TimeMakeAgent;
        	else 
        		iTimeMakeAgent = 1600 - ((level - 6) * 200);
        	
        	return iTimeMakeAgent;
    		
    	}
    }
    
    /**
     * @author Antonio Javier Garrido Rodrguez
     * Clase creada para referenciar a los sonidos de efectos.
     */
    public static class Sounds{
	
    	public static final int Boing = 0;
    	public static final int Click = 1;
    	public static final int Coins = 2;
    	public static final int Eraser = 3;
    	public static final int Kid_Laugh = 4;
    	public static final int Goat = 5;
    	public static final int Peop = 6;
    	public static final int Applause = 7;
	
    }

}