

package com.example.game;

import android.app.Activity;
import android.content.Context;
import android.content.SharedPreferences;

/**
 * Clase utilizada para persistir datos en la memoria del telfono.
 * 
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class SharedPreferencesManager {
	
	private SharedPreferences _sharedPref;
	
	public SharedPreferencesManager(Activity activity)
	{
		_sharedPref =  activity.getPreferences(Context.MODE_PRIVATE);
	}
	
	/**
	 * Almacena en la memoria del telfono el dato value con una key asociada.
	 * @param key: string key asociado al dato.
	 * @param value: valor del dato a almacenar.
	 */
	public void writeIntToSharedPreferences(String key, int value)
	{
		SharedPreferences.Editor editor = _sharedPref.edit();
		editor.putInt(key, value);
		editor.commit();
	}
	
	/**
	 * Elimina de la memoria del telfono el valor asociado a la key dada.
	 * @param key: string key asociado al dato.
	 */
	public void removeEntryToSharedPreferences(String key)
	{
		SharedPreferences.Editor editor = _sharedPref.edit();
		editor.remove(key);
		editor.commit();
	}
	
	/**
	 * Lee de la memoria del telfono el valor asociado a la key dada.
	 * @param key: string key asociado al dato.
	 * @return entero asociado a la key dada, en caso de no existir dicha key, devuelve -1.
	 */
	public int readIntFromSharedPrefences(String key)
	{
		int defaultValue = -1;
		
		//Si no encuentra la key especificada devuelve defaultValue
		return _sharedPref.getInt(key, defaultValue);
		
	}

}
