package com.example.game;

import java.util.Random;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Rect;
 
/**
 *Clase utilizada para representar a un agente letra.
 *
 * @author Antonio Javier Garrido Rodrguez
 * Copyright 2014 Antonio Javier Garrido Rodrguez
 * 
 *  This file is part of Kamikawa.

    Kamikawa is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Kamikawa is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Kamikawa.  If not, see <http://www.gnu.org/licenses/>.
 */
public class Sprite {
	
	   //Indica el nmero del filas del bmp
	   private static final int BMP_ROWS = 4;
	   //Indica el nmero del columnas del bmp
	   private static final int BMP_COLUMNS = 3;	
	   //Coordenada x
	   private int x; 
	   //Coordenada y
	   private int y;
       //Velocidad de movimiento en el eje x
	   private int xSpeed;
       //Velocidad de movimiento en el eje y
	   private int ySpeed;
       
	   private GameView gameView;
       private Bitmap bmp;
       //Identificador de la imagen bmp que lo representa
       private int resource;
     //Identificador de la imagen bmp que lo representa en rojo.
       private int resource_red;
       //Indica el muequito de la imagen que se est mostrando, con respecto a la columna (0,1,2)
       private int currentFrame = 0;
       //Ancho del bmp
       private int width;
       //Alto del bmp
       private int height;
       //Nivel actual
       private int level = 1;
       
       //Indica la letra que representa el agente
       private String _letra;
       
      
       /**
        * Inicializa los valores de configuracin para un agente letra.
     * @param gameView referencia al SurfaceView
     * @param resource referencia al bmp que representa al agente
     * @param resource_red referencia al bmp que representa al agente en rojo
     * @param level nivel actual
     * @param letra letda que representa el agente
     */
     public Sprite(GameView gameView, int resource, int resource_red, int level, String letra) 
     {
    	this.gameView=gameView;
        this.resource = resource;
        this.resource_red = resource_red;
        this.level = level;
        _letra = letra;
             
        //Cargo el bmp por defecto a memoria
        this.bmp = BitmapFactory.decodeResource(this.gameView.getResources(), this.resource);
             
        //Ancho y alto de un muequito
        this.width = bmp.getWidth() / BMP_COLUMNS;
        this.height = (bmp.getHeight() / BMP_ROWS) + 2;
             
        //La velocidad de movimiento del agente es determinada en funcin al nivel
        xSpeed = this.level;
        ySpeed = this.level;
             
        Random rnd = new Random(System.currentTimeMillis());
             
        //Establece una posicin inical donde aparecer el agente, de forma aleatoria, teniendo en cuenta los lmites de la pantalla
        x = rnd.nextInt(gameView.getWidth() - width);
        y = rnd.nextInt((gameView.getHeight() - gameView.getHeightControlsBottom()) - height);       
    }
 
    	/**
    	 * Metodo para desplazar al agente por la pantalla (eje X, eje Y)
    	 */
     	private void update() 
     	{
    	   
			//Si el agente est en el extremo derecho o izquierdo de la pantalla, entonces cambiamos en el eje x el sentido
	    	if (x >= gameView.getWidth() - width - xSpeed || x + xSpeed <= 0) 
			{
				xSpeed = -xSpeed;
			}
			x = x + xSpeed;
			
			//Si el agente est en el extremo inferior o superior de la pantalla, entonces cambiamos en el eje y el sentido
			if (y >= (gameView.getHeight() - gameView.getHeightControlsBottom()) - height - ySpeed || y + ySpeed <= 0) 
			{
				ySpeed = -ySpeed;
			}
			
			y = y + ySpeed;
			
			//Dentro de la imagen que representa al agente (matriz 4 x 3), para la fila actual (segn direccin actual) vamos cambiando la imagen
			//para cada paso que da el agente, es decir, un paso con la columna 0, siguiente con la 1, siguiente con la 2, siguiente paso con 0...
			currentFrame = ++currentFrame % BMP_COLUMNS;
       }
      
       
       /**
       * Pinta al agente en la pantalla.
       * @param canvas
       */
       public void onDraw(Canvas canvas) 
       { 
           //Actualiza su posicin en la pantalla
    	   update();
           
           int srcX = currentFrame * width;
           int srcY = getAnimationRow() * height;
    
           Rect src = new Rect(srcX, srcY, srcX + width, srcY + height);
           Rect dst = new Rect(x, y, x + width, y + height);
           
           canvas.drawBitmap(bmp, src, dst, null);
       }
       
       
    /** La direccin de movimiento depende del signo de las variaciones en el eje X e Y.
     * A cada una de las cuatro posibles combinaciones de signos en las variaciones, le asigno una fila de la matriz imagen del agente.
     * As consigo que el agente se muestre andando en las 4 direcciones posibles, segn hacia la direccin que camine:
     * (+, -) incremento positivo en el eje X y negativo en el eje Y, ira hacia arriba, representado por la fila 3 de la matriz imagen.
     * (-, -), ira hacia la izquierda, representado por la fila 1.
     * (+, +), ira hacia la derecha, representado por la fila 2.
     * (-, +), ira hacia abajo, representado por la fila 0.
     *
     * @return int indicando la fila de la matriz que debe mostrar.
     */   
    private int getAnimationRow() {
           
    	   //Por defecto devolvemos fila 3, cuadrante superior derecho (de frente)
    	   int iRowAnimation = 3;
    	   
    	   //Si agente se encuentra en el cuadrante inferior derecho
    	   if(xSpeed >= 0 && ySpeed > 0)
    		   iRowAnimation = 2;
    	 //Si agente se encuentra en el cuadrante superior izquierdo
    	   else if(xSpeed <= 0 && ySpeed < 0)
    		   iRowAnimation = 1;
    	 //Si agente se encuentra en el cuadrante inferior izquierdo
      	   else if(xSpeed < 0 && ySpeed >= 0)
    		   iRowAnimation = 0;
    		   
    	   return iRowAnimation;
    	   
       }
       
     /**
      * Determina si el punto pasado por parmetro colisiona o est contenido dentro del rea que ocupa el agente.
     * @param xTouch coordenada x del punto.
     * @param yTouch coordenada y del punto.
     * @return true si el punto colisiona o est contenido dentro del rea del agente, o false en caso contrario.
     */
     public boolean isCollision(float xTouch, float yTouch) 
     {
           return (xTouch >= x && xTouch <= x + width) && (yTouch >= y && yTouch <= y + height);
     }
       
       
     /**
     * Devuelve la letra que representa el agente.
     * @return String con la letra que representa el agente.
     */
    public String getLetra()
     {
    	   return _letra;
     }
       
     
    /**
     * Cambia el bmp actual por el mismo pero en rojo.
     */
    public void changeColourToRed()
     {
    	   //Cambio el bmp actual por el mismo pero en rojo
    	   bmp = BitmapFactory.decodeResource(this.gameView.getResources(), this.resource_red);
    	          
           //Redefino ancho y alto del muequito, por si el tamao cambia ligeramente
           this.width = bmp.getWidth() / BMP_COLUMNS;
           this.height =  (bmp.getHeight() / BMP_ROWS) + 2;
       
     }
       
     
     /**
     * Cambio el bmp al suyo por defecto, es decir, azul. 
     */
    public void changeColourToDefault()
     {
           //Cambio al bmp por defecto
           this.bmp = BitmapFactory.decodeResource(this.gameView.getResources(), this.resource);
           
           //Redefino ancho y alto del muequito, por si el tamao cambia ligeramente
           this.width = bmp.getWidth() / BMP_COLUMNS;
           this.height = (bmp.getHeight() / BMP_ROWS) + 2;
       
     }
       
     /**
     * Devuelve la coordenada x del agente.
     * @return entero con la coordenada x.
     */
    public int getCoordinateX()
     {
    	 return x;
     }
       
     /**
     * Devuelve la coordenada y del agente.
     * @return entero con la coordenada y.
     */
    public int getCoordinateY()
     {
    	 return y;
     }
       
     
     /**
     * Devuelve el ancho del bmp que representa al agente.
     * @return ancho del bmp.
     */
    public int getWidth()
     {
    	 return width;
     }
       
     /**
     * Devuelve la altura del bmp que representa al agente.
     * @return altura del bmp.
     */
    public int getHeight()
     {
    	 return height;
     }
       
     /**
     * Invierte la direccin de movimiento de un agente. 
     */
    public void changeDirection()
     {
    	 xSpeed = -xSpeed;
    	 ySpeed = -ySpeed;
     }
       
}  